/*
 *  config.h
 *
 *  Configuration parameters for compiling.  Contains among other
 *  things all the stupid limits you really want to be without, all the
 *  smart limits that has to be there to make it impossible to crash
 *  the server, and lots of constants and configuration options.
 */


#define DEBUG			/* We're still debugging and want traces. */

/*
 * Add some checks that really shouldn't be necessary.
 */
#define DEFENSIVE_CHECKS


/* Collating sequence used. */
#define DEFAULT_COLLAT_TAB	swedish_collate_tab



/* The file kom_perror prints to.  */
/* Yes! This should be stdout. At least during testing and debugging! /ceder */

#define kom_errout	stdout

/*
 * Security options (these must be #defines since they are used inside a
 *		     'const' definition in kom-types.c).
 */
#define ANYONE_CAN_CREATE_NEW_PERSONS TRUE /* Can a created person */
					   /* create other persons? */
#define CREATE_PERSON_BEFORE_LOGIN  TRUE /* Can a person create himself? */
#define ANYONE_CAN_CREATE_NEW_CONFS TRUE
#define DEFAULT_CHANGE_NAME	    TRUE /* Everyone is normally allowed */
					 /* to change their own name. */

/*
 * The following are constants which can not be changed without rewriting
 * some of the code.
 */
#define PROTOCOL_NUMBER_BASE 10	/* The number base used in all communication
				 * between server and clients. */


/* Where to save things. These are used by ramkomd. */

extern const char *DEFAULT_DBASE_DIR;
extern const char *DATAFILE_NAME;
extern const char *BACKUPFILE_NAME;
extern const char *TEXTFILE_NAME;
extern const char *STATISTIC_NAME;
extern const char *PID_NAME;
extern const char *MEMUSE_NAME;

/* Communications */

extern const char * DEFAULT_CLIENT_SERVICE;
extern const char * DEFAULT_MUX_SERVICE;

#if 0
extern const int IN_CLIENT_PORT;	/* Which port does LysKOM listen to? */
extern const int IN_MUX_PORT;	        /* Which port does LysKOM listen to? */
#endif

/*
 * The following should always be true:
 * SYNCTIMEOUT <= GARBTIMEOUT <= TIMEOUT
 * Times in milliseconds.
 */
extern const int TIMEOUT;	/* Timeout to select() when totally idle. */
extern const int GARBTIMEOUT;	/* Timeout to select() when garbing texts
				   but not syncing. */
extern const int SYNCTIMEOUT;	/* Timeout to select() when syncing. */

extern const int GARB_INTERVAL;	/* In minutes. */
extern const int SYNC_INTERVAL;	/* In minutes. */
extern const int SYNC_RETRY_INTERVAL;	/* In minutes. */

/* Size of the cache. (only applies to diskomd). */

extern const int CACHE_CONFERENCES;
extern const int CACHE_PERSONS;
extern const int CACHE_TEXT_STATS;

/* String limits */

extern const int CONF_NAME_LEN;	/* Conference (and Person) name */
extern const int PWD_LEN;	/* Password. It is not guaranteed that all
				   chars are significant. */
extern const int WHAT_DO_LEN;	/* what_am_i_doing */
extern const int USERNAME_LEN;	/* Max login-id from clients */
extern const int TEXT_LEN;	/* Max len of a text. */
extern const int BROADCAST_LEN;	/* Max len of a broadcast message */

/* Text_stat limits */

extern const int MAX_MARKS_PERSON; /* Max marks per person */
extern const int MAX_MARKS_TEXT;  /* Max marks per text */
extern const int MAX_RECIPIENTS;  /* Max recipients/cc_recipients per text */
extern const int MAX_COMM;	  /* Max number of comments to a text */
extern const int MAX_FOOT;	  /* Max number of footnotes to a text */
extern const int MAX_CREA_MISC;   /* Sum of recipients, cc_recipients, comm_to
				   * and footn_to must not exceed MAX_CREA_MISC
				   * when the text is created. */

/*
 * Some other limits
 */
extern const int MAX_NO_OF_CONNECTIONS;	/* the maximum number of persons
					 * that can use Kom simultaneously */
extern const int MARK_AS_READ_CHUNK;	/* You can't mark more than this many
					 * texts as read in one call. */

/*
 * Max number of nested super_confs a message will be forwarded before
 * the server gives up.
 */
extern const int MAX_SUPER_CONF_LOOP;


extern const int DEFAULT_NICE;	/* Number of days a text normally lives. */

/* Max entries in the per-client transmit queue */
extern const int MAXQUEUEDSIZE;

/* Max entries in the per-client transmit queue to send at any one time */
extern const int MAXDEQUEUELEN;

/* What is whitespace? */
extern const unsigned char *WHITESPACE;
