/*
 * File: numlist2.c
 * 
 * This file is supposed to be a reference while testing numlist.
 *
 * Author: Inge Wallin
 */


#include <stdio.h>
#include <stdlib.h>

#include <misc-types.h>

#include "numlist2.h"


Numlist *
Numlist_create()
{
    Numlist  * nl;
    int        i;

    nl = (Numlist *) malloc(sizeof(Numlist));
    if (nl == NULL) {
	fprintf(stderr, "Virtual memory exhausted");
	abort();
    }

    for (i = 0; i < NUM_CELLS; ++i)
	nl->cells[i] = 0;
    
    return nl;
}


Bool
numlist_isempty(Numlist *nl)
{
    int   i;

    for (i = 0; i < NUM_CELLS; ++i)
	if (nl->cells[i] != 0)
	    return FALSE;
    
    return TRUE;
}


Bool
numlist_member(Numlist *nl, u_long num)
{
    return (nl->cells[num / 32] & ((u_long) 1 << (num & 31))) != 0;
}


u_long
numlist_first(Numlist *nl)
{
    int   i;
    int   j;

    if (numlist_isempty(nl))
	return NUMLIST_ERR;

    for (i = 0; i < NUM_CELLS; ++i) {
	if (nl->cells[i] != 0) {
	    for (j = 31; j >= 0; --j) {
		if ((nl->cells[i] & ((u_long) 1 << j)) != 0)
		    return i * 32 + j;
	    }
	}
    }
    
    return NUMLIST_ERR;
}


u_long
numlist_next(Numlist *nl, u_long num)
{
    /* NYI */
    return NUMLIST_ERR;
}


void
numlist_insert(Numlist *nl, u_long num)
{
    nl->cells[num / 32] |= ((u_long) 1 << (num & 31));
}


void
numlist_delete(Numlist *nl, u_long num)
{
    nl->cells[num / 32] &= ~((u_long) 1 << (num & 31));
}

